Struct FontStretch
pub struct FontStretch(pub(super) u16);typst only.Expand description
The width of a font.
Tuple Fields
0: u16Implementations
impl FontStretch
impl FontStretch
pub const ULTRA_CONDENSED: FontStretch
pub const ULTRA_CONDENSED: FontStretch
Ultra-condensed stretch (50%).
pub const EXTRA_CONDENSED: FontStretch
pub const EXTRA_CONDENSED: FontStretch
Extra-condensed stretch weight (62.5%).
pub const CONDENSED: FontStretch
pub const CONDENSED: FontStretch
Condensed stretch (75%).
pub const SEMI_CONDENSED: FontStretch
pub const SEMI_CONDENSED: FontStretch
Semi-condensed stretch (87.5%).
pub const NORMAL: FontStretch
pub const NORMAL: FontStretch
Normal stretch (100%).
pub const SEMI_EXPANDED: FontStretch
pub const SEMI_EXPANDED: FontStretch
Semi-expanded stretch (112.5%).
pub const EXPANDED: FontStretch
pub const EXPANDED: FontStretch
Expanded stretch (125%).
pub const EXTRA_EXPANDED: FontStretch
pub const EXTRA_EXPANDED: FontStretch
Extra-expanded stretch (150%).
pub const ULTRA_EXPANDED: FontStretch
pub const ULTRA_EXPANDED: FontStretch
Ultra-expanded stretch (200%).
pub fn from_ratio(ratio: Ratio) -> FontStretch
pub fn from_ratio(ratio: Ratio) -> FontStretch
Create a font stretch from a ratio between 0.5 and 2.0, clamping it if necessary.
pub fn from_number(stretch: u16) -> FontStretch
pub fn from_number(stretch: u16) -> FontStretch
Create a font stretch from an OpenType-style number between 1 and 9, clamping it if necessary.
pub fn from_wdth(value: AxisValue) -> FontStretch
pub fn from_wdth(value: AxisValue) -> FontStretch
Maps an OpenType wdth font variation value to a stretch.
pub fn to_ratio(self) -> Ratio
pub fn to_ratio(self) -> Ratio
The ratio between 0.5 and 2.0 corresponding to this stretch.
pub fn to_wdth(self) -> AxisValue
pub fn to_wdth(self) -> AxisValue
Maps an OpenType wdth font variation value to a stretch.
pub fn round(self) -> FontStretch
pub fn round(self) -> FontStretch
Round to one of the pre-defined variants.
pub fn distance(self, other: FontStretch) -> Ratio
pub fn distance(self, other: FontStretch) -> Ratio
The absolute ratio distance between this and another font stretch.