Struct FontWeight
pub struct FontWeight(pub(super) u16);Expand description
The weight of a font.
Tuple Fields
0: u16Implementations
impl FontWeight
Font weight names and numbers.
See <https://developer.mozilla.org/en-US/docs/Web/CSS/@font-face/font-weight#common_weight_name_mapping>
impl FontWeight
Font weight names and numbers.
See <https://developer.mozilla.org/en-US/docs/Web/CSS/@font-face/font-weight#common_weight_name_mapping>
pub const THIN: FontWeight
pub const THIN: FontWeight
Thin weight (100).
pub const EXTRALIGHT: FontWeight
pub const EXTRALIGHT: FontWeight
Extra light weight (200).
pub const LIGHT: FontWeight
pub const LIGHT: FontWeight
Light weight (300).
pub const REGULAR: FontWeight
pub const REGULAR: FontWeight
Regular weight (400).
pub const MEDIUM: FontWeight
pub const MEDIUM: FontWeight
Medium weight (500).
pub const SEMIBOLD: FontWeight
pub const SEMIBOLD: FontWeight
Semibold weight (600).
pub const BOLD: FontWeight
pub const BOLD: FontWeight
Bold weight (700).
pub const EXTRABOLD: FontWeight
pub const EXTRABOLD: FontWeight
Extrabold weight (800).
pub const BLACK: FontWeight
pub const BLACK: FontWeight
Black weight (900).
pub fn from_number(weight: u16) -> FontWeight
pub fn from_number(weight: u16) -> FontWeight
Create a font weight from a number between 100 and 900, clamping it if necessary.
pub fn thicken(self, delta: i16) -> FontWeight
pub fn thicken(self, delta: i16) -> FontWeight
Add (or remove) weight, saturating at the boundaries of 100 and 900.
pub fn distance(self, other: FontWeight) -> u16
pub fn distance(self, other: FontWeight) -> u16
The absolute number distance between this and another font weight.