pub struct TextItem {
origin: DVec3,
basis: (DVec3, DVec3),
text: String,
font: TextFont,
fill_rgbas: AlphaColor<Srgb>,
stroke_rgbas: AlphaColor<Srgb>,
stroke_width: f32,
items: RefCell<Option<Vec<VItem>>>,
inline_length_em: Cell<Option<f64>>,
}Expand description
Simple single-line text item
Fields
origin: DVec3Origin
basis: (DVec3, DVec3)Basis
text: StringText content
font: TextFontFont info
fill_rgbas: AlphaColor<Srgb>Fill color
stroke_rgbas: AlphaColor<Srgb>Stroke color
stroke_width: f32Stroke width
items: RefCell<Option<Vec<VItem>>>Cached items
inline_length_em: Cell<Option<f64>>cached text inline size
Implementations
Sourceimpl TextItem
impl TextItem
Sourcepub fn inline_length_em(&self) -> f64
pub fn inline_length_em(&self) -> f64
Get inline length in em units
Sourcepub fn text_box(&self) -> Parallelogram
pub fn text_box(&self) -> Parallelogram
Returns the text outline box starting from baseline origin to the width of last character and em height.
fn generate_items(&self) -> Vec<VItem>
fn items(&self) -> Ref<'_, Vec<VItem>>
fn transform_items(&self, transformation: impl FnOnce(&mut Vec<VItem>))